package sun.awt;

import java.awt.Graphics;
import java.awt.image.BufferedImage;
import java.awt.image.Raster;
import java.awt.image.DataBufferInt;
import java.awt.image.DirectColorModel;
import java.awt.color.ColorSpace;
import sun.awt.image.ImageRepresentation;
import sun.awt.image.ToolkitImage;
import java.util.Arrays;
import java.awt.Image;

public class IconInfo
{
    private int[] intIconData;
    private long[] longIconData;
    private Image image;
    private final int width;
    private final int height;
    private int scaledWidth;
    private int scaledHeight;
    private int rawLength;
    
    public IconInfo(int[] original) {
        this.intIconData = ((null == original) ? null : Arrays.copyOf(original, original.length));
        this.width = original[0];
        this.height = original[1];
        this.scaledWidth = this.width;
        this.scaledHeight = this.height;
        this.rawLength = this.width * this.height + 2;
    }
    
    public IconInfo(long[] original) {
        this.longIconData = ((null == original) ? null : Arrays.copyOf(original, original.length));
        this.width = (int)original[0];
        this.height = (int)original[1];
        this.scaledWidth = this.width;
        this.scaledHeight = this.height;
        this.rawLength = this.width * this.height + 2;
    }
    
    public IconInfo(Image image) {
        this.image = image;
        if ((image instanceof ToolkitImage)) {
            ImageRepresentation imageRep = ((ToolkitImage)image).getImageRep();
            imageRep.reconstruct(32);
            this.width = imageRep.getWidth();
            this.height = imageRep.getHeight();
        }
        else {
            this.width = image.getWidth(null);
            this.height = image.getHeight(null);
        }
        this.scaledWidth = this.width;
        this.scaledHeight = this.height;
        this.rawLength = this.width * this.height + 2;
    }
    
    public void setScaledSize(int scaledWidth, int scaledHeight) {
        this.scaledWidth = scaledWidth;
        this.scaledHeight = scaledHeight;
        this.rawLength = scaledWidth * scaledHeight + 2;
    }
    
    public boolean isValid() {
        return this.width > 0 && this.height > 0;
    }
    
    public int getWidth() {
        return this.width;
    }
    
    public int getHeight() {
        return this.height;
    }
    
    @Override
    public String toString() {
        return "IconInfo[w=" + this.width + ",h=" + this.height + ",sw=" + this.scaledWidth + ",sh=" + this.scaledHeight + "]";
    }
    
    public int getRawLength() {
        return this.rawLength;
    }
    
    public int[] getIntData() {
        if (this.intIconData == null) {
            if (this.longIconData != null) {
                this.intIconData = longArrayToIntArray(this.longIconData);
            }
            else if (this.image != null) {
                this.intIconData = imageToIntArray(this.image, this.scaledWidth, this.scaledHeight);
            }
        }
        return this.intIconData;
    }
    
    public long[] getLongData() {
        if (this.longIconData == null) {
            if (this.intIconData != null) {
                this.longIconData = intArrayToLongArray(this.intIconData);
            }
            else if (this.image != null) {
                this.longIconData = intArrayToLongArray(imageToIntArray(this.image, this.scaledWidth, this.scaledHeight));
            }
        }
        return this.longIconData;
    }
    
    public Image getImage() {
        if (this.image == null) {
            if (this.intIconData != null) {
                this.image = intArrayToImage(this.intIconData);
            }
            else if (this.longIconData != null) {
                this.image = intArrayToImage(longArrayToIntArray(this.longIconData));
            }
        }
        return this.image;
    }
    
    private static int[] longArrayToIntArray(long[] array) {
        int[] array2 = new int[array.length];
        for (int i = 0; i < array.length; ++i) {
            array2[i] = (int)array[i];
        }
        return array2;
    }
    
    private static long[] intArrayToLongArray(int[] array) {
        long[] array2 = new long[array.length];
        for (int i = 0; i < array.length; ++i) {
            array2[i] = (long)array[i];
        }
        return array2;
    }
    
    static Image intArrayToImage(int[] dataArray) {
        return new BufferedImage(new DirectColorModel(ColorSpace.getInstance(1000), 32, 16711680, 65280, 255, -16777216, false, 3), Raster.createPackedRaster(new DataBufferInt(dataArray, dataArray.length - 2, 2), dataArray[0], dataArray[1], dataArray[0], new int[] { 16711680, 65280, 255, -16777216 }, null), false, null);
    }
    
    static int[] imageToIntArray(Image image, int n, int h) {
        if (n <= 0 || h <= 0) {
            return null;
        }
        DirectColorModel cm = new DirectColorModel(ColorSpace.getInstance(1000), 32, 16711680, 65280, 255, -16777216, false, 3);
        DataBufferInt dataBuffer = new DataBufferInt(n * h);
        Graphics graphics = new BufferedImage(cm, Raster.createPackedRaster(dataBuffer, n, h, n, new int[] { 16711680, 65280, 255, -16777216 }, null), false, null).getGraphics();
        graphics.drawImage(image, 0, 0, n, h, null);
        graphics.dispose();
        int[] data = dataBuffer.getData();
        int[] array = new int[n * h + 2];
        array[0] = n;
        System.arraycopy(data, 0, array, 2, n * (array[1] = h));
        return array;
    }
}
